﻿//
//  MulticastUdpServer.cs
//
//  Author:
//       tsntsumi <tsntsumi at tsntsumi.com>
//
//  Copyright (c) 2015 tsntsumi
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU Lesser General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

/// @file
/// <summary>
/// Multicast UDP server.
/// </summary>
/// @since 2015.8.20
using System;
using System.Net;
using System.Net.Sockets;

namespace SocketNet
{
	/// <summary>
	/// UDP Multicast server.
	/// </summary>
	public class UdpMulticastServer: UdpServer
	{
		/// <summary>
		/// コンストラクタ。
		/// </summary>
		/// <param name="multicastAddress">ジョインするマルチキャストIPアドレス。</param>
		/// <param name="port">バインドするポート番号。</param>
		public UdpMulticastServer (IPAddress multicastAddress, int port)
			: base(IPAddress.Any, port, TransmissionType.Multicast)
		{
			MulticastAddress = multicastAddress;
		}

		/// <summary>
		/// UdpClient を作成して、マルチキャストグループに参加させます。
		/// </summary>
		/// <param name="ipEndPoint">IPエンドポイント。</param>
		protected override void Setup(IPEndPoint ipEndPoint)
		{
			base.Setup(ipEndPoint);
			udpClient.JoinMulticastGroup(MulticastAddress);
		}

		/// <summary>
		/// Udpサーバを停止します。
		/// </summary>
		public override void Stop()
		{
			acceptingConnections = false;

			if (udpClient != null)
			{
				udpClient.DropMulticastGroup(IPAddress);

				udpClient.Close();
			}
		}
	}
}

